/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import { CellTemplateDirective } from '../rendering/cell-template.directive';
import { GroupHeaderTemplateDirective } from '../grouping/group-header-template.directive';
import { GroupHeaderColumnTemplateDirective } from '../grouping/group-header-column-template.directive';
import { EditTemplateDirective } from '../editing/edit-template.directive';
import { ColumnSortSettings } from './sort-settings';
import { GroupFooterTemplateDirective } from '../grouping/group-footer-template.directive';
import { ColumnBase } from './column-base';
import { FilterCellTemplateDirective } from '../filtering/cell/filter-cell-template.directive';
import { FilterMenuTemplateDirective } from '../filtering/menu/filter-menu-template.directive';
import { IdService } from '../common/id.service';
import { FieldDataType } from '../common/field-datatype';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare function isColumnComponent(column: any): column is ColumnComponent;
/**
 * Represents a column in the Grid.
 *
 * Use the `kendo-grid-column` component to define columns in the Grid.
 *
 * @example
 * ```html
 * <kendo-grid [data]="gridData">
 *   <kendo-grid-column field="ProductID" title="Product ID"></kendo-grid-column>
 *   <kendo-grid-column field="ProductName" title="Product Name"></kendo-grid-column>
 *   <kendo-grid-column field="UnitPrice" title="Unit Price"></kendo-grid-column>
 * </kendo-grid>
 * ```
 * @remarks
 * Supported children components are: {@link StringFilterCellComponent}, {@link NumericFilterCellComponent}, {@link BooleanFilterCellComponent}, {@link DateFilterCellComponent}, {@link StringFilterMenuComponent}, {@link NumericFilterMenuComponent}, {@link BooleanFilterMenuComponent}, {@link DateFilterMenuComponent}, {@link FilterCellOperatorsComponent}, {@link ColumnMenuAutoSizeAllColumnsComponent}, {@link ColumnMenuAutoSizeColumnComponent}, {@link ColumnMenuChooserComponent}, {@link ColumnMenuComponent}, {@link ColumnMenuFilterComponent}, {@link ColumnMenuItemComponent}, {@link ColumnMenuLockComponent}, {@link ColumnMenuPositionComponent}, {@link ColumnMenuSortComponent}, {@link ColumnMenuStickComponent}.
 */
export declare class ColumnComponent extends ColumnBase {
    /**
     * Sets the field that the column binds to.
     */
    field: string;
    /**
     * Sets the format for displaying the column value.
     * For supported date and number formats, see the [Column Formats](slug:formats_columns_grid) article.
     */
    format: any;
    /**
     * Enables sorting when the user clicks the column header. [See example](slug:sorting_grid).
     * Emits the `sortChange` event.
     *
     * @default true
     */
    sortable: boolean | ColumnSortSettings;
    /**
     * Allows dragging the column to the group panel.
     * Set to `false` to group by this column only through the Grid API.
     *
     * @default true
     */
    groupable: boolean;
    /**
     * Sets the editor type for the column. [See example](slug:inline_editing_grid#toc-using-reactive-forms).
     * Used when the column enters edit mode.
     *
     * @default 'text'
     */
    editor: FieldDataType;
    /**
     * Sets the filter type for the filter row UI. [See example](slug:filtering_grid#toc-filter-data-types).
     *
     * @default 'text'
     */
    filter: FieldDataType;
    /**
     * Shows or hides the filter UI for this column. [See example](slug:filtering_grid).
     *
     * @default true
     */
    filterable: boolean;
    /**
     * Sets whether the column is editable. [See example](slug:make_fields_uneditable_grid).
     *
     * @default true
     */
    editable: boolean;
    template: CellTemplateDirective;
    groupHeaderTemplate: GroupHeaderTemplateDirective;
    groupHeaderColumnTemplate: GroupHeaderColumnTemplateDirective;
    groupFooterTemplate: GroupFooterTemplateDirective;
    editTemplate: EditTemplateDirective;
    filterCellTemplate: FilterCellTemplateDirective;
    filterMenuTemplate: FilterMenuTemplateDirective;
    constructor(parent?: ColumnBase, idService?: IdService);
    get templateRef(): TemplateRef<any>;
    get groupHeaderTemplateRef(): TemplateRef<any>;
    get groupHeaderColumnTemplateRef(): TemplateRef<any>;
    get groupFooterTemplateRef(): TemplateRef<any>;
    get editTemplateRef(): TemplateRef<any>;
    get filterCellTemplateRef(): TemplateRef<any>;
    get filterMenuTemplateRef(): TemplateRef<any>;
    get displayTitle(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnComponent, [{ optional: true; host: true; skipSelf: true; }, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnComponent, "kendo-grid-column", never, { "field": { "alias": "field"; "required": false; }; "format": { "alias": "format"; "required": false; }; "sortable": { "alias": "sortable"; "required": false; }; "groupable": { "alias": "groupable"; "required": false; }; "editor": { "alias": "editor"; "required": false; }; "filter": { "alias": "filter"; "required": false; }; "filterable": { "alias": "filterable"; "required": false; }; "editable": { "alias": "editable"; "required": false; }; }, {}, ["template", "groupHeaderTemplate", "groupHeaderColumnTemplate", "groupFooterTemplate", "editTemplate", "filterCellTemplate", "filterMenuTemplate"], never, true, never>;
}
